#
# spec file for package lxqt-panel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-panel
Version:        1.2.1
Release:        bp155.1.9
Summary:        Desktop Panel for LXQt
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libsensors4-devel
BuildRequires:  lxqt-build-tools-devel >= 0.11.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Solid) >= 5.36.0
BuildRequires:  cmake(KF5WindowSystem) >= 5.36.0
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5DBus) >= 5.12.0
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbusmenu-qt5)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libstatgrab)
BuildRequires:  pkgconfig(lxqt) >= 1.1.0
BuildRequires:  pkgconfig(lxqt-globalkeys) >= 1.1.0
BuildRequires:  pkgconfig(lxqt-globalkeys-ui)
BuildRequires:  pkgconfig(sysstat-qt5)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xtst)
Requires:       lxmenu-data
Recommends:     %{name}-lang

%description
Brand new desktop Panel for LXQt

%lang_package

%package devel
Summary:        Devel files for lxqt-panel
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
BuildArch:      noarch

%description devel
LXQt panel development files and headers

%prep
%setup -q

%build
%define _lto_cflags %{nil}
export CXXFLAGS="%{optflags} $(pkg-config --cflags xkbcommon-x11)"
%cmake -DPULL_TRANSLATIONS=No -DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now"

%install
%cmake_install
%fdupes -s %{buildroot}/%{_datadir}

%find_lang %{name} --with-qt

%files
%license LICENSE
%doc AUTHORS CHANGELOG
%{_bindir}/%{name}
%dir %{_datadir}/desktop-directories/
%dir %{_datadir}/lxqt
%dir %{_sysconfdir}/xdg
%dir %{_sysconfdir}/xdg/autostart
%dir %{_sysconfdir}/xdg/menus
%config %{_sysconfdir}/xdg/menus/lxqt-applications.menu
%config %{_sysconfdir}/xdg/menus/lxqt-applications-compact.menu
%config %{_sysconfdir}/xdg/menus/lxqt-applications-simple.menu
%{_libdir}/%{name}
%{_datadir}/lxqt/panel
%{_datadir}/lxqt/lxqt-panel
%{_datadir}/lxqt/panel/qeyes-types
%{_mandir}/man1/lxqt-panel.1%{?ext_man}
%config %{_sysconfdir}/xdg/autostart/lxqt-panel.desktop
%{_datadir}/desktop-directories/lxqt-leave.directory
%{_datadir}/desktop-directories/lxqt-settings.directory
%{_datadir}/lxqt/panel.conf

%files devel
%license LICENSE
%{_includedir}/lxqt

%files lang -f %{name}.lang
%license LICENSE
%dir %{_datadir}/lxqt/translations/
%{_datadir}/lxqt/translations/%{name}

%changelog
* Mon Jan  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.2.1:
  * Fixed a regression in volume popup.
  * Added Qeyes plugin.
  * Avoid covering fullscreen windows.
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Added context items to Quick Launch for reloading desktop entries.
  * Set window flags of the volume popup explicitly (useful under Wayland).
  * Fixed Quick Launch icons when there are multiple config files.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Now the legacy tray icons are shown inside Status Notifier when
    the System Tray plugin is enabled. That removes some problems
    of the old tray widget.
  * Reset buttons are fixed in config dialogs.
  * Desktop names are shown in the context menus of task buttons.
  * The panel config dialog is split into 3 sections, for having a sleeker GUI.
  * The clash between the main menu shortcut and the built-in
    shortcuts of the search entry is fixed.
  * Added options for the button label and style of Directory Menu.
  * Fixed resetting of System Statistics graph on auto-hiding panels.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Added "Custom Command" plugin.
  * Added context menu and drag-and-drop support to search results of main menu.
  * Better icon handling in Status Notifier.
  * Fixed the keypad navigation in main menu.
  * Prevented sliding of volume tooltip.
  * Removed special treatment of Openbox and Compton configs.
* Fri Apr 16 2021 Andreas Stieger <andreas.stieger@gmx.de>
- lxqt-panel-0.17.1:
  * Fix compilation against Qt < 5.15
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * Optionally auto-hide panel only when it overlaps a window.
  * Workaround for an issue with glibc 2.33 on old Docker engines.
  * Fixed the popup of grouped task button in a special case.
  * Fixed changing of world clock's time zone with mouse wheel.
  * Code cleanup and modernization.
* Fri Nov  6 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.1:
  * Fixed compilation with Qt 5.12 and Qt 5.13.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Use a stylesheet for progress-bars of Sensors plugin.
  * Implemented auto-hiding for Status Notifier.
  * Added option to task button for moving the window to
    next monitor.
  * Added option to place task buttons of new windows next to the
    existing ones of same class when task buttons are ungrouped.
  * Removed incorrect and redundant explanation of milliseconds
    from World Clock.
  * Don't call non-const member functions on temporaries.
  * Prevent possible C++11 range loop container detachment.
  * Fixed the sizes and alignments of some plugins at startup.
  * Added right-click menu to main menu items.
  * Address deprecation warnings/errors.
  * Added XF86Eject button action.
* Wed May 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.15.1:
  * Fix a mistake in keyboard indicator flag, which could create a
    huge amount of error messages.
  * Loosen the conditions for panel positioning. Now, the panel can
    be at virtual screen edges but not between screens.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-panel.keyring to tsujan's key
* Fri Apr 24 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Added BuildRequires for cmake(Qt5Concurrent)
- Update to version 0.15.0
  * A new plugin is added for changing display backlight.
  * The option "Show only active desktop" is added to Desktop Switcher.
  * A basic country flag support is added to Keyboard status indicator.
  * An option is added to Task Manager for moving window to next/previous virtual desktop with mouse wheel.
  * An option is added to Volume Control for toggling volume notifications with keyboard.
  * Better text eliding and painting of Task Manager buttons.
  * Smoother menu search.
  * Fixed icons of applications like Skype, Doscord,… in Status Notifier (new tray).
  * Fixed cut text in World Clock.
  * Icons are fetched in an appropriate size to avoid scaling and bluring in Task Manager.
  * Fixed panel positioning with multiple screens.
  * Made Quick Launch respect Panel's lock state.
  * Override the menu icon size only if a custom font size is selected.
  * Fixed a crash in LXQtTaskButton under kwin_wayland.
  * Fixed high CPU usage in Desktop Switcher.
  * Fixes and enhancements to the old tray plugin.
  * Other code fixes and cleanups.
* Fri Jul 12 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1141204).
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Remove pointless ldconfig calls (there are no SLPPed libraries
  here, just plugins).
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * New in plugin-spacer: Added auto-expansion feature
  * Deprecated plugin-clock
  * plugin-colorpicker: Removed content margins and reduced spacing
  * plugin-mainmenu: Filtering can be done by typing the executable name (when Panel is compiled without menu-cache – the default)
  * plugin-mount: Device names are correctly shown on removal
  * plugin-panel: Optional overriding of icon theme for panels
  * plugin-panel: Allow plugin’s “static” configuration change
  * plugin-volume: Do not auto-unmute on volume change
  * plugin-worldclock: Set manual format dialog title
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Remove BuildRequire for pkgconfig(libmenu-cache):
  Seems to create problems under some conditions.
  See https://forum.lxqt.org/t/release-lxqt-0-13-0/301
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Fixes for main menu, especially its correct update when new apps are installed.
  * No menu-cache by default (fixing problems caused by menu-cache + systemd)
  * Fixes for task button text and icon
  * Move and Resize windows in task-button context menu
  * Fixes for worldclock
  * Avoid infinite recursion when no icon available
  * Fix wrongly positioned popups
  * Plugin-volume: Use a specific icon for the panel
  * Better integration between keyboard indicator plugin and keyboard configuration
* Mon Nov  6 2017 mvetter@suse.com
- Use pkg-config to determine cflags:
  SR#535177 changed the location of xkbcommon-x11.h.
  So far the path was hardcoded, now use pkg-config to determine
  the actual path.
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * quicklaunch: Show popup menu aligned to clicked button
  * quicklaunch: Add "Desktop Action" support
  * l10n: Update Polish translation
  * Fix Danish spelling
  * plugin-tray: Fix dupe icon display error
  * Don't export github templates
  * Use worldclock by default instead of clock.
  * clock: Show deprecation message on startup/add
  * Fix clock text update
  * Avoid calling text() in MatchAction on a QAction == 0
  * volume: Do check for OSS availability in run-time
  * Update Polish .desktop entry
  * Remove space from end of "Show popup on mouse hover " string
  * Updated Lithuanian translation
  * Add/update Lithuanian translation
  * Update directorymenu_it.desktop
  * mainmenu: Don't hold the references for menu-cache
  * mainmenu: Fix menu-cache usage
  * set Qt::AA_UseHighDpiPixmaps to true
  * l10n: Updated Polish translation
  * Improved lxqt-panel version display
  * Added default CMAKE_BUILD_TYPE and LXQT_PANEL_PATCH_VERSION
  * plugins: Make widgets/buttons use whole space
  * LXQtPanelLayout: Honor item's expanding size policy
  * mainmenu: Install eventFiler for all (sub)menus
  * volume: Add all changes notifications (configurable)
  * Fixes a FTBFS in superbuild mode
  * Added merged autostart and menu to CMakeLists.txt
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * translation: Add Portugese directories
  * Update desktop entries and Replace fr_FR by fr
  * Merge pull request #45 from lxde/menu-comment
  * lxqt-applications.menu: remove accidentally added topics from "System Tools"
  * Update Greek translation (el) Remove country variant from language code
  * Rename LxQt to LXQt everywhere
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Adds double quotes to everything that may break
  * Use GNUINnstallDirs
  * Updates the build system to use the Targets infrastructure
  * Place LXQt About over Preferences in the main menu
  * Added italian translation in menu
  * Added german translation for the settings directory.
  * Drops hardcoded /etc/xdg paths
  * menu: hungarian translations added
  * Add Russian translation
  * Restore the old preferences menu layout of razor-qt.
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * add lxqt-leave directory files
  * use LXQt-specific menu file
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Fit the task group to its contents
  * mainmenu: Add "true" translucency support
  * Show "unknown" when an icon is missing
  * volume: Force step for wheel over popup slider
  * volume: Always show tooltip over button
  * volume: Force configured step for wheel over button
  * volume: Use "override" keyword
  * Enable translucency for taskbar group popup
  * tray: Move tray icon window into correct place
  * taskbar: Elide texts of buttons when needed
  * volume: Fix calculating of alsa volume
  * volume: Remove duplicated code
  * volume: Fix reporting of pulse volume
  * sysstat: Fix saving of network maximum speed
  * mainmenu: Redesign config dialog
  * mainmenu: Clear search upon show (configurable)
  * plugin-kbindicator: Undef the "explicit" workaround
  * plugin-sysstat: Avoid "set but unused var" warning
  * panel: Make space reserve on display configurable
  * panel: Add wrong logic warning
  * panel: Hide correctly upon the DragLeave
  * plugin-mount: Fix firing the actions
  * plugin-mount: Notify just on "real" add/remove
  * plugin: Save settings before signal connect
  * taskbar: Add Meta+1..9 shortcuts to raise windows
  * Bump year
- Remove 0001-lxqt_panel_override_explicit_keyword.patch: upstreamed
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Show Auto-Hiding Panels with Delay (#387)
  * Enabling testing on weston (#380)
  * Update *da.desktop files
  * plugin-showdesktop: Cleanup left behind XCB artifacts
  * plugin-kbindicator: Use FindXCB CMake module
  * plugin-tray: Use the FindXCB CMake module
  * Use the new lxqt-build-tools CMake modules (FindMenuCache)
  * plugin-desktopswitch: Add LABEL_TYPE_NONE
  * Add/Update Portugese translations
  * taskbar: Add "cycle on wheel" configuration
  * taskbar: Forward wheelEvent
  * Add/Update french desktop entries
  * taskbar: Set toolButtonStyle for popup correctly
  * Fix faulty link in README.md
  * Remove arbitrary limit of taskbar button width
  * Remove cpack (#371)
- Added 0001-lxqt_panel_override_explicit_keyword.patch
  * Fixes compile errors  https://github.com/lxde/lxqt/issues/1251
- Added CXXFLAGS change from X11:LXQT:git for libxkbcommon-x11
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Update README.md: Reflect changes introduced in 1c22479
  * CMakeLists: Fail for unmet dependencies
  * mainmenu: Remove setting base style in StyleChange
  * mainmenu: Workaround transparent search
  * mainmenu: Dispose old menu first when building new
  * Add README.md
  * sensors: Add default bar scale
  * sensors: Check for existence of the max value
  * sensors: Add minor code optimization
  * mainmenu: Handle QAction disposal correctly
  * panel: Don't use autoFillBackground
  * Plugin: Fix FTBFS for older Qt versions
  * mainmenu: Fix show/hide actions after menu rebuild
  * Statusnotifier: Remove setParent on StatusNotifierMenu.
  * Add XKB_COMMON_X11_INCLUDE_DIRS
  * panel: Remove/deprecate plugin-screensaver (#363)
  * Add and Update Arabic Translations for Desktop Files
  * Fix updating panel geometry on screen size change
  * panel: Fix screen number config change saving
  * Separate a String for I18N Enhancement
  * plugin: Force config dialog activation/raise
  * plugin: Fix crossreferencing of config dialogs
  * panel: Dispose unneeded menu
  * panel: Destroy panel's config dialog
  * showPopupMenu: Remove extraneous setParent() call (#359)
  * statusnotifier: fix popup position on right click
  * desktopswitch: Take layoutDirection into account
  * taskbar: Remove orientation specific logic for DnD
  * LXQtPanelLayout: Take layoutDirection into account
  * taskbar: Remove forgotten debug
  * taskbar: Consider layoutDirection for DnD
  * panel: Optimize search a bit
  * plugin-volume: Avoid an buffer overflow
  * Respect the OnlyShowIn property for menu entries when using menu-cache (#351)
  * kbindicator-plugin: fix linking with libxcb-1.12
  * plugin-volume: Handle errors when trying to determine the next card
  * Clean up CMakeLists.txt
  * plugin/directorymenu: Removes no use code (#350)
  * build: Forward translations parameters
  * ts-files removal (#346)
  * Fix memory leaks
  * Use const references with the foreach iterator
  * Small fix
  * statusnotifier: Fix showing icons in menu
  * kbindicator: (Re)Add .desktop translations
  * Update desktopswitchconfiguration.ui
  * panel: (Re)Add translations dir
  * Revert unintended *.desktop files removal
  * Remove translations (can be pulled in build time)
  * Use external translations
  * Update lxqt-panel_it.ts
  * Add documentation/comments for PanelPluginsModel.
  * Fix segfault on plugin initialization (#338)
  * translations: updated german translation (#323)
  * plugin-mainmenu: update mainmenu_it.ts (#337)
  * Russian translation update
  * mainmenu: Use style sheet to override icon
  * plugins: Change "repolish" logic
  * mainmenu: Reduce delay of popup when using shortcut
  * volume: Remove debug
  * plugins: Don't unload -> avoid dangling resources
  * Added new translated strings.
  * Added missing context for lupdate.
  * Updated german translation.
  * Ask for confirmation when removing a panel
  * panel: Add "Lock Panel" functionality
  * fix updating panel geometry on screen changes
  * Try find a free position when adding a new panel
  * LXQtPanelApplication: Use D-Pointers
  * Animate auto-hiding panels.
  * Add QT_USE_QSTRINGBUILDER to the compile definitions
  * tray: Fix SEGFAULT on stop
  * mainmenu: Fix visual search problems
  * mainmenu: Remove duplicates from search
  * mainmenu: Add new configuration options for search
  * mainmenu: Workadound QLineEdit's wakups(QTBUG-52021)
  * mainmenu: Add configurable way of search
  * taskbar: separate adding from changing windows
  * plugins: Make buttons flat for cleaner look
  * mainmenu: Fix search interacion
  * mainmenu: Add search/hide possibility
  * taskbar: Add show icon by WindowClass to config
  * taskbar: Use icon from theme (based on windowClass)
  * panellayout: Do not allow oversized plugins
  * panellayout: Avoid plugin margins
  * PluginSettings: Make settings object/class public
  * Bump year Fix licenses: lxqt-panel is pure LGPL
  * worldclock: Fix possible SEGFAULT
  * Add comments for ILXQtPanel and LXQtPanel.
  * plugin-taskbar: fix German translation of configuration dialogue
  * panel: Correct PanelPluginsModel logic
  * volume: Avoid infinite cycle in config dialog
  * plugins: Use "cleaner" style logic
  * mainmenu: Remove unneeded includes
  * mainmenu: Fix freeze for some widget styles (e.g. breeze)
  * tray: Fix "BadDamage" warning message
  * tray: Postpone tray icon initialization
  * PluginSettings: Emit settingsChanged only for owned keys
  * taskbar: Fix (auto)hide after window menu is shown
  * mainmenu: Use directory of current icon for search
  * mainmenu: Fix showing icon path in configuration
  * plugin-taskbar: avoid icon-only style for groups
  * statusnotifier: fix position of context menus
  * plugin-quicklaunch: remove preset applications
  * plugin-tray: Fix native window sizes for high DPI devices
  * taskbar: Refactor/improove window handling logic
  * taskbar: Fix multiple groups when WindowClass changes
  * plugin settings: Publish PluginSettings symbols
  * Add support for nested groups in PluginSettings
  * Add PluginSettings::{read,set}Array for atomicity
  * Add PluginSettings for shared settings for plugins
  * plugins config: remove a lot of redundant code
  * LXQtPanelPluginConfigDialog: add ctor overload
  * Update lxqt-panel_fr_FR.ts
  * Create HR translations for panel and plugins
  * lxqt-panel: Update/format and install man page
  * plugin-kbindicator: remove ru_RU translations
  * plugin-kbindicator: add russian translations
  * Update Russian translations for the panel and plugins
  * Italian translation update
  * Updated german translation.
  * Adds comments for lxqtpanelapplication.h.
  * Correct some minor spelling mistakes.
  * panel-config: Fix background opacity slider
  * taskbar: Avoid "noop" button if window ID changes
  * mainmenu: Fix URL assembly for Drag&Drop
  * panel: Fill background
  * mainmenu: Use configurable icon
  * worldclock: Fix update interval
  * panel: Add periodic hide checking
  * clock: Fix content update if transform/autorotate
  * quicklaunch: Fix panel hiding upon showing menu
  * worldclock: Decrease (unnecessary) wake-ups
  * panel: Remove periodic checking for hide
  * Prevent panel hiding in case any (standalone) window shown
  * plugins: Unify window popup-ing
  * directorymenu: Fix indentation (spaces)
  * panel: Use override for overriden virt func
  * hu translations fixed
  * plugin-sysstat: translations fix
  * desktop-switch: Hightlight only windows in taskbar
  * fix misspelled prefered
- Add keyring
- Remove xkbcommon-includes.patch: upstreamed
- Remove: lxqt-panel-xcb-1.12.patch upstreamed
- Remove: no-undefined.patch instead pass
  - DCMAKE_MODULE_LINKER_FLAGS="-Wl,--as-needed -Wl,-z,now" to
  cmake to not have the --no-undefined which doesnt make sense here
  since the symbol is in the binary and not in a library.
* Wed Jun  1 2016 dimstar@opensuse.org
- Add lxqt-panel-xcb-1.12.patch: Fix linking with libxcb-1.12:
  we use xcb symbols by ourselves, so we are also responsible to
  link libxcb.
* Tue May 24 2016 mvetter@suse.com
- Use pkgconfig to require libxkbcommon-x11-devel
- Require lxqt-mount to have mounter option working
* Wed Dec 23 2015 mvetter@suse.com
- Use lxmenu-data to have a working panel menu (fonts etc).
* Mon Nov  9 2015 hrvoje.senjan@gmail.com
- Added no-undefined.patch: include sources which export used functions
- Added xkbcommon-includes.patch: explicitly add include path for
  xkbcommon headers, otherwise they are picked up accidentally
- Enable mount and kbindicator plugins
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
  We have to compile it with -DKBINDICATOR_PLUGIN=No -DMOUNT_PLUGIN=No
  for now because we have problems otherwise.
  Deleted patches:
  - lxqt-panel-0.9.0_fix_lxqtmount_include.patch
  - lxqt-panel-0.9.0_add_libxcb_to_cmakelist.patch
  Not needed anymore
* Thu Jul  9 2015 mvetter@suse.com
- Use correct name "lxqt" instead of "lxde-qt"
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%include to use cmake macros
- Added Patches:
  + lxqt-panel-0.9.0_fix_lxqtmount_include.patch
  + lxqt-panel-0.9.0_add_libxcb_to_cmakelist.patch
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Dropped Patches:
  + lxqt-panel-0.8.0_fix_lxqt-mount_headers.patch
  + lxqt-panel-0.8.0_fix_undefined_reference.patch
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora Builds
* Wed Nov 19 2014 andrea@opensuse.org
- fixed license tag
* Thu Nov 13 2014 andrea@opensuse.org
- added lxmenu-data
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Fri Oct  3 2014 sfalken@opensuse.org
- Added:
  * 0001-fix_plugin_mount.patch
  * 0002-fix_plugin_volume.patch
  * 0003-fix_plugin_worldclock.patch
  * 0004-fix_plugin_kbindicator.patch
  * 0005-fix_plugin_dom.patch
  * Patches added to fix buildfailure caused by undefined references, and new default build flags in cmake (gh#lxde/lxde-qt#288)
* Tue May 13 2014 andrea@opensuse.org
- Build all plugins adding sensors and libstatgrab to buildrequires
* Tue May 13 2014 andrea@opensuse.org
- spec file clean up for factoy
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora spec, split into subproject
  Del: lxqt-panel-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- Ran spec-cleaner on openSUSE specfile
* Sat May 10 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-panel-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-panel-0.7.0.tar.xz
  Del:  _service
* Mon Apr  7 2014 sfalken@opensuse.org
-  Changed Requires: lxqt-globalkeys-devel to lxwt-globalkeys
* Wed Apr  2 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-panel.spec
  Add: lxqt-panel.changes
